.. MetPyRad documentation master file, created by
   sphinx-quickstart on Thu Jan 30 18:29:16 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

MetPyRad documentation
======================

.. warning::

   This project is under active development. The public API should not be considered stable.

**Date**: Feb 13, 2025
**Version**: 0.0.1

**Useful links**:
`Source repository <https://github.com/lmri-met/metpyrad>`_ |
`Issues & ideas <https://github.com/lmri-met/metpyrad/issues>`_ |
`Binary installers <https://pypi.org/project/metpyrad/>`_

Welcome to **MetPyRad**’s documentation!
MetPyRad is an open source, GPLv3-licensed library providing a collection of tools for radionuclide metrology for the Python programming language.

MetPyRad allows processing measurements for a given radionuclide using a **Hidex 300 SL** automatic liquid scintillator counter.
It is designed to facilitate the handling, analysis, and visualization of measurement data.

.. grid:: 1 2 2 2
    :gutter: 4
    :class-container: sd-text-center

    .. grid-item-card:: Tutorials

        +++

        In this section you will find step-by-step lessons that
        guide beginners through the initial setup and basic usage of MetPyRad.

        .. button-ref:: tutorials
            :ref-type: ref
            :color: primary
            :shadow:

            To the tutorials

    .. grid-item-card:: How-to guides

        +++

        In this section you will find step-by-step instructions to solve specific problems using MetPyRad.
        It assumes some knowledge of how MetPyRad works.

        .. button-ref:: howtos
            :ref-type: ref
            :color: primary
            :shadow:

            To the how-to guides

    .. grid-item-card:: API reference

        +++

        In this section you will find detailed descriptions of the MetPyRad public interface.
        It describes how it works and how to use it.
        It assumes some understanding of the key concepts.

        .. button-ref:: api
            :ref-type: ref
            :color: primary
            :shadow:

    .. grid-item-card:: Topic guides

        +++

        In this section you will find discussions about key topics and concepts related to MetPyRad.
        It provides useful background information and in-depth explanations.

        .. button-ref:: topics
            :ref-type: ref
            :color: primary
            :shadow:

            To the topic guides

.. toctree::
    :caption: Content
    :titlesonly:
    :hidden:

    tutorials/index
    howtos/index
    api/index
    topics/index
    about

Dummy text for testing automatic documentation deploy.